@@ -11,18 +11,10 @@ from lightwood.encoders.text.vocab import VocabularyEncoder
 from lightwood.encoders.text.rnn import RnnEncoder as TextRnnEncoder
 from lightwood.encoders.categorical.onehot import OneHotEncoder
 from lightwood.encoders.categorical.autoencoder import CategoricalAutoEncoder
-from lightwood.encoders.time_series.ts_fresh_ts import TsFreshTsEncoder
 from lightwood.encoders.time_series.rnn import RnnEncoder as TsRnnEncoder
 # from lightwood.encoders.audio.amplitude_ts import AmplitudeTsEncoder
 from lightwood.encoders.categorical.multihot import MultiHotEncoder
 
-try:
-    from lightwood.encoders.time_series.cesium_ts import CesiumTsEncoder
-    export_cesium = True
-except:
-    export_cesium = False
-    print('Failed to export cesium timeseires encoder')
-
 
 class DateTime:
     DatetimeEncoder = DatetimeEncoder
@@ -51,11 +43,7 @@ class Categorical:
     CategoricalAutoEncoder = CategoricalAutoEncoder
 
 class TimeSeries:
-    TsFreshTsEncoder = TsFreshTsEncoder
     TsRnnEncoder = TsRnnEncoder
-    if export_cesium:
-        CesiumTsEncoder = CesiumTsEncoder
-
 
 class BuiltinEncoders:
     DateTime = DateTime
